# pylint: disable=too-many-lines,too-many-statements, line-too-long
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from io import IOBase
import json
import sys
from typing import Any, Callable, Dict, IO, Optional, TypeVar, Union, cast, overload

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.polling import AsyncLROPoller, AsyncNoPolling, AsyncPollingMethod
from azure.core.polling.async_base_polling import AsyncLROBasePolling
from azure.core.rest import AsyncHttpResponse, HttpRequest
from azure.core.tracing.decorator_async import distributed_trace_async
from azure.core.utils import case_insensitive_dict

from ... import models as _models
from ..._model_base import SdkJSONEncoder, _deserialize
from ..._operations._operations import build_radiology_insights_infer_radiology_insights_request
from .._vendor import RadiologyInsightsClientMixinABC

if sys.version_info >= (3, 9):
    from collections.abc import MutableMapping
else:
    from typing import MutableMapping  # type: ignore  # pylint: disable=ungrouped-imports
JSON = MutableMapping[str, Any]  # pylint: disable=unsubscriptable-object
T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]]


class RadiologyInsightsClientOperationsMixin(RadiologyInsightsClientMixinABC):
    async def _infer_radiology_insights_initial(
        self, body: Union[_models.RadiologyInsightsData, JSON, IO[bytes]], **kwargs: Any
    ) -> JSON:
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = kwargs.pop("params", {}) or {}

        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[JSON] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _content = None
        if isinstance(body, (IOBase, bytes)):
            _content = body
        else:
            _content = json.dumps(body, cls=SdkJSONEncoder, exclude_readonly=True)  # type: ignore

        _request = build_radiology_insights_infer_radiology_insights_request(
            content_type=content_type,
            api_version=self._config.api_version,
            content=_content,
            headers=_headers,
            params=_params,
        )
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.endpoint", self._config.endpoint, "str", skip_quote=True),
        }
        _request.url = self._client.format_url(_request.url, **path_format_arguments)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            _request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [202]:
            if _stream:
                await response.read()  # Load the body in memory and close the socket
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response)

        response_headers = {}
        response_headers["Operation-Location"] = self._deserialize("str", response.headers.get("Operation-Location"))
        response_headers["Retry-After"] = self._deserialize("int", response.headers.get("Retry-After"))
        response_headers["Repeatability-Result"] = self._deserialize(
            "str", response.headers.get("Repeatability-Result")
        )

        deserialized = _deserialize(JSON, response.json())

        if cls:
            return cls(pipeline_response, deserialized, response_headers)  # type: ignore

        return deserialized  # type: ignore

    @overload
    async def begin_infer_radiology_insights(
        self, body: _models.RadiologyInsightsData, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.RadiologyInsightsInferenceResult]:
        # pylint: disable=line-too-long
        """Create Radiology Insights job.

        Creates a Radiology Insights job with the given request body.

        :param body: Required.
        :type body: ~azure.healthinsights.radiologyinsights.models.RadiologyInsightsData
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :return: An instance of AsyncLROPoller that returns RadiologyInsightsInferenceResult. The
         RadiologyInsightsInferenceResult is compatible with MutableMapping
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.healthinsights.radiologyinsights.models.RadiologyInsightsInferenceResult]
        :raises ~azure.core.exceptions.HttpResponseError:

        Example:
            .. code-block:: python

                # JSON input template you can fill out and use as your body input.
                body = {
                    "patients": [
                        {
                            "id": "str",  # A given identifier for the patient. Has to be
                              unique across all patients in a single request. Required.
                            "encounters": [
                                {
                                    "id": "str",  # The id of the visit.
                                      Required.
                                    "class": "str",  # Optional. The class of the
                                      encounter. Known values are: "inpatient", "ambulatory",
                                      "observation", "emergency", "virtual", and "healthHome".
                                    "period": {
                                        "end": "2020-02-20 00:00:00",  #
                                          Optional. End time with inclusive boundary, if not ongoing.
                                        "start": "2020-02-20 00:00:00"  #
                                          Optional. Starting time with inclusive boundary.
                                    }
                                }
                            ],
                            "info": {
                                "birthDate": "2020-02-20",  # Optional. The patient's
                                  date of birth.
                                "clinicalInfo": [
                                    {
                                        "resourceType": "str",  # The type of
                                          resource. Required.
                                        "id": "str",  # Optional. Resource
                                          Id.
                                        "implicitRules": "str",  # Optional.
                                          A set of rules under which this content was created.
                                        "language": "str",  # Optional.
                                          Language of the resource content.
                                        "meta": {
                                            "lastUpdated": "str",  #
                                              Optional. When the resource last changed - e.g. when the
                                              version changed.
                                            "profile": [
                                                "str"  # Optional. A
                                                  list of profiles (references to `StructureDefinition
                                                  <https://www.hl7.org/fhir/structuredefinition.html>`_
                                                  resources) that this resource claims to conform to.
                                                  The URL is a reference to `StructureDefinition.url
                                                  <https://www.hl7.org/fhir/structuredefinition-definitions.html#StructureDefinition.url>`_.
                                            ],
                                            "security": [
                                                {
                                                    "code":
                                                      "str",  # Optional. Symbol in syntax defined by
                                                      the system.
                                                    "display":
                                                      "str",  # Optional. Representation defined by the
                                                      system.
                                                    "extension":
                                                      [
                                                        {
                "url": "str",  # Source of the definition
                                                              for the extension code - a logical name
                                                              or a URL. Required.
                "valueBoolean": bool,  # Optional. Value
                                                              as boolean.
                "valueCodeableConcept": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional. Plain text
                                                                  representation of the concept.
                },
                "valueDateTime": "str",  # Optional.
                                                              Value as dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                              integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time
                                                                  with inclusive boundary, if not
                                                                  ongoing.
                "start": "str"  # Optional. Starting
                                                                  time with inclusive boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                                  alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "system": "str",  # Optional. The
                                                                      namespace for the identifier
                                                                      value.
                "type": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional.
                                                                          Plain text representation of
                                                                          the concept.
                },
                "use": "str",  # Optional. usual
                                                                      | official | temp | secondary |
                                                                      old (If known).
                "value": "str"  # Optional. The
                                                                      value that is unique.
                },
                "reference": "str",  # Optional.
                                                                  Literal reference, Relative, internal
                                                                  or absolute URL.
                "type": "str"  # Optional. Type the
                                                                  reference refers to (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                                  points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "period": 0.0,  # Number of
                                                                  milliseconds between samples.
                                                                  Required.
                "data": "str",  # Optional. Decimal
                                                                  values with spaces, or "E" | "U" |
                                                                  "L".
                "factor": 0.0,  # Optional. Multiply
                                                                  data by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                                  limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                                  limit of detection.
                },
                "valueString": "str",  # Optional. Value
                                                              as string.
                "valueTime": "12:30:00"  # Optional.
                                                              Value as time (hh:mm:ss).
                                                        }
                                                    ],
                                                    "id": "str",
                                                      # Optional. Unique id for inter-element
                                                      referencing.
                                                    "system":
                                                      "str",  # Optional. Identity of the terminology
                                                      system.
                                                    "version":
                                                      "str"  # Optional. Version of the system - if
                                                      relevant.
                                                }
                                            ],
                                            "source": "str",  # Optional.
                                              A uri that identifies the source system of the resource.
                                              This provides a minimal amount of Provenance information
                                              that can be used to track or differentiate the source of
                                              information in the resource. The source may identify
                                              another FHIR server, document, message, database, etc.
                                            "tag": [
                                                {
                                                    "code":
                                                      "str",  # Optional. Symbol in syntax defined by
                                                      the system.
                                                    "display":
                                                      "str",  # Optional. Representation defined by the
                                                      system.
                                                    "extension":
                                                      [
                                                        {
                "url": "str",  # Source of the definition
                                                              for the extension code - a logical name
                                                              or a URL. Required.
                "valueBoolean": bool,  # Optional. Value
                                                              as boolean.
                "valueCodeableConcept": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional. Plain text
                                                                  representation of the concept.
                },
                "valueDateTime": "str",  # Optional.
                                                              Value as dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                              integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time
                                                                  with inclusive boundary, if not
                                                                  ongoing.
                "start": "str"  # Optional. Starting
                                                                  time with inclusive boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                                  alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "system": "str",  # Optional. The
                                                                      namespace for the identifier
                                                                      value.
                "type": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional.
                                                                          Plain text representation of
                                                                          the concept.
                },
                "use": "str",  # Optional. usual
                                                                      | official | temp | secondary |
                                                                      old (If known).
                "value": "str"  # Optional. The
                                                                      value that is unique.
                },
                "reference": "str",  # Optional.
                                                                  Literal reference, Relative, internal
                                                                  or absolute URL.
                "type": "str"  # Optional. Type the
                                                                  reference refers to (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                                  points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "period": 0.0,  # Number of
                                                                  milliseconds between samples.
                                                                  Required.
                "data": "str",  # Optional. Decimal
                                                                  values with spaces, or "E" | "U" |
                                                                  "L".
                "factor": 0.0,  # Optional. Multiply
                                                                  data by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                                  limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                                  limit of detection.
                },
                "valueString": "str",  # Optional. Value
                                                              as string.
                "valueTime": "12:30:00"  # Optional.
                                                              Value as time (hh:mm:ss).
                                                        }
                                                    ],
                                                    "id": "str",
                                                      # Optional. Unique id for inter-element
                                                      referencing.
                                                    "system":
                                                      "str",  # Optional. Identity of the terminology
                                                      system.
                                                    "version":
                                                      "str"  # Optional. Version of the system - if
                                                      relevant.
                                                }
                                            ],
                                            "versionId": "str"  #
                                              Optional. The version specific identifier, as it appears
                                              in the version portion of the URL. This value changes
                                              when the resource is created, updated, or deleted.
                                        }
                                    }
                                ],
                                "sex": "str"  # Optional. The patient's sex. Known
                                  values are: "female", "male", and "unspecified".
                            },
                            "patientDocuments": [
                                {
                                    "content": {
                                        "sourceType": "str",  # The type of
                                          the content's source. In case the source type is 'inline',
                                          the content is given as a string (for instance, text). In
                                          case the source type is 'reference', the content is given as
                                          a URI. Required. Known values are: "inline" and "reference".
                                        "value": "str"  # The content of the
                                          document, given either inline (as a string) or as a reference
                                          (URI). Required.
                                    },
                                    "id": "str",  # A given identifier for the
                                      document. Has to be unique across all documents for a single
                                      patient. Required.
                                    "type": "str",  # The type of the patient
                                      document, such as 'note' (text document) or 'fhirBundle' (FHIR
                                      JSON document). Required. Known values are: "note", "fhirBundle",
                                      "dicom", and "genomicSequencing".
                                    "administrativeMetadata": {
                                        "encounterId": "str",  # Optional.
                                          Reference to the encounter associated with the document.
                                        "orderedProcedures": [
                                            {
                                                "code": {
                                                    "coding": [
                                                        {
                "code": "str",  # Optional. Symbol in
                                                              syntax defined by the system.
                "display": "str",  # Optional.
                                                              Representation defined by the system.
                "extension": [
                {
                "url": "str",  # Source of the
                                                                      definition for the extension code
                                                                      - a logical name or a URL.
                                                                      Required.
                "valueBoolean": bool,  #
                                                                      Optional. Value as boolean.
                "valueCodeableConcept": ...,
                "valueDateTime": "str",  #
                                                                      Optional. Value as dateTime.
                "valueInteger": 0,  # Optional.
                                                                      Value as integer.
                "valuePeriod": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional.
                                                                          Coded form of the unit.
                "comparator": "str",  #
                                                                          Optional. < | <= | >= | > -
                                                                          how to understand the value.
                "system": "str",  # Optional.
                                                                          System that defines coded
                                                                          unit form.
                "unit": "str",  # Optional.
                                                                          Unit representation.
                "value": 0.0  # Optional.
                                                                          Numerical value (with
                                                                          implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "low": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "numerator": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                }
                },
                "valueReference": {
                "display": "str",  #
                                                                          Optional. Text alternative
                                                                          for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  #
                                                                                  Optional. End time
                                                                                  with inclusive
                                                                                  boundary, if not
                                                                                  ongoing.
                "start": "str"  #
                                                                                  Optional. Starting
                                                                                  time with inclusive
                                                                                  boundary.
                },
                "system": "str",  #
                                                                              Optional. The namespace
                                                                              for the identifier value.
                "type": ...,
                "use": "str",  #
                                                                              Optional. usual |
                                                                              official | temp |
                                                                              secondary | old (If
                                                                              known).
                "value": "str"  #
                                                                              Optional. The value that
                                                                              is unique.
                },
                "reference": "str",  #
                                                                          Optional. Literal reference,
                                                                          Relative, internal or
                                                                          absolute URL.
                "type": "str"  # Optional.
                                                                          Type the reference refers to
                                                                          (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of
                                                                          sample points at each time
                                                                          point. Required.
                "origin": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "period": 0.0,  # Number of
                                                                          milliseconds between samples.
                                                                          Required.
                "data": "str",  # Optional.
                                                                          Decimal values with spaces,
                                                                          or "E" | "U" | "L".
                "factor": 0.0,  # Optional.
                                                                          Multiply data by this before
                                                                          adding to origin.
                "lowerLimit": 0.0,  #
                                                                          Optional. Lower limit of
                                                                          detection.
                "upperLimit": 0.0  #
                                                                          Optional. Upper limit of
                                                                          detection.
                },
                "valueString": "str",  #
                                                                      Optional. Value as string.
                "valueTime": "12:30:00"  #
                                                                      Optional. Value as time
                                                                      (hh:mm:ss).
                }
                ],
                "id": "str",  # Optional. Unique id for
                                                              inter-element referencing.
                "system": "str",  # Optional. Identity of
                                                              the terminology system.
                "version": "str"  # Optional. Version of
                                                              the system - if relevant.
                                                        }
                                                    ],
                                                    "text": "str"
                                                      # Optional. Plain text representation of the
                                                      concept.
                                                },
                                                "description": "str",
                                                  # Optional. Procedure description.
                                                "extension": [
                                                    {
                "url": "str",  # Source of the definition for
                                                          the extension code - a logical name or a URL.
                                                          Required.
                "valueBoolean": bool,  # Optional. Value as
                                                          boolean.
                "valueCodeableConcept": {
                "coding": [
                {
                "code": "str",  # Optional.
                                                                      Symbol in syntax defined by the
                                                                      system.
                "display": "str",  # Optional.
                                                                      Representation defined by the
                                                                      system.
                "extension": [
                ...
                ],
                "id": "str",  # Optional. Unique
                                                                      id for inter-element referencing.
                "system": "str",  # Optional.
                                                                      Identity of the terminology
                                                                      system.
                "version": "str"  # Optional.
                                                                      Version of the system - if
                                                                      relevant.
                }
                ],
                "text": "str"  # Optional. Plain text
                                                              representation of the concept.
                                                        },
                "valueDateTime": "str",  # Optional. Value as
                                                          dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                          integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time with
                                                              inclusive boundary, if not ongoing.
                "start": "str"  # Optional. Starting time
                                                              with inclusive boundary.
                                                        },
                "valueQuantity": {
                "code": "str",  # Optional. Coded form of
                                                              the unit.
                "comparator": "str",  # Optional. < | <=
                                                              | >= | > - how to understand the value.
                "system": "str",  # Optional. System that
                                                              defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                              representation.
                "value": 0.0  # Optional. Numerical value
                                                              (with implicit precision).
                                                        },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                }
                                                        },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                }
                                                        },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                              alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional. End
                                                                      time with inclusive boundary, if
                                                                      not ongoing.
                "start": "str"  # Optional.
                                                                      Starting time with inclusive
                                                                      boundary.
                },
                "system": "str",  # Optional. The
                                                                  namespace for the identifier value.
                "type": {
                "coding": [
                {
                "code": "str",  #
                                                                              Optional. Symbol in
                                                                              syntax defined by the
                                                                              system.
                "display": "str",  #
                                                                              Optional. Representation
                                                                              defined by the system.
                "extension": [
                ...
                ],
                "id": "str",  # Optional.
                                                                              Unique id for
                                                                              inter-element
                                                                              referencing.
                "system": "str",  #
                                                                              Optional. Identity of the
                                                                              terminology system.
                "version": "str"  #
                                                                              Optional. Version of the
                                                                              system - if relevant.
                }
                ],
                "text": "str"  # Optional. Plain
                                                                      text representation of the
                                                                      concept.
                },
                "use": "str",  # Optional. usual |
                                                                  official | temp | secondary | old (If
                                                                  known).
                "value": "str"  # Optional. The value
                                                                  that is unique.
                },
                "reference": "str",  # Optional. Literal
                                                              reference, Relative, internal or absolute
                                                              URL.
                "type": "str"  # Optional. Type the
                                                              reference refers to (e.g. "Patient").
                                                        },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                              points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "period": 0.0,  # Number of milliseconds
                                                              between samples. Required.
                "data": "str",  # Optional. Decimal
                                                              values with spaces, or "E" | "U" | "L".
                "factor": 0.0,  # Optional. Multiply data
                                                              by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                              limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                              limit of detection.
                                                        },
                "valueString": "str",  # Optional. Value as
                                                          string.
                "valueTime": "12:30:00"  # Optional. Value as
                                                          time (hh:mm:ss).
                                                    }
                                                ]
                                            }
                                        ]
                                    },
                                    "authors": [
                                        {
                                            "fullName": "str",  #
                                              Optional. Text representation of the full name.
                                            "id": "str"  # Optional.
                                              author id.
                                        }
                                    ],
                                    "clinicalType": "str",  # Optional. The type
                                      of the clinical document. Known values are: "consultation",
                                      "dischargeSummary", "historyAndPhysical", "radiologyReport",
                                      "procedure", "progress", "laboratory", and "pathologyReport".
                                    "createdDateTime": "2020-02-20 00:00:00",  #
                                      Optional. The date and time when the document was created.
                                    "language": "str",  # Optional. A 2 letter
                                      ISO 639-1 representation of the language of the document.
                                    "specialtyType": "str"  # Optional. specialty
                                      type the document. Known values are: "pathology" and "radiology".
                                }
                            ]
                        }
                    ],
                    "configuration": {
                        "includeEvidence": bool,  # Optional. An indication whether the
                          model's output should include evidence for the inferences.
                        "inferenceOptions": {
                            "findingOptions": {
                                "provideFocusedSentenceEvidence": bool  # Optional.
                                  If this is true, provide the sentence that contains the first token
                                  of the finding's clinical indicator (i.e. the medical problem), if
                                  there is one. This sentence is provided as an extension with url
                                  'ci_sentence', next to the token evidence. Default is false.
                            },
                            "followupRecommendationOptions": {
                                "includeRecommendationsInReferences": bool,  #
                                  Optional. Include/Exclude follow-up recommendations in references to
                                  a guideline or article. Default is false.
                                "includeRecommendationsWithNoSpecifiedModality":
                                  bool,  # Optional. Include/Exclude follow-up recommendations without
                                  a specific radiology procedure. Default is false.
                                "provideFocusedSentenceEvidence": bool  # Optional.
                                  If this is true, provide one or more sentences as evidence for the
                                  recommendation, next to the token evidence. The start and end
                                  positions of these sentences will be put in an extension with url
                                  'modality_sentences'. Default is false.
                            }
                        },
                        "inferenceTypes": [
                            "str"  # Optional. This is a list of inference types to be
                              inferred for the current request. It could be used if only part of the
                              Radiology Insights inferences are required. If this list is omitted or
                              empty, the model will return all the inference types.
                        ],
                        "locale": "str",  # Optional. Local for the model to use. If not
                          specified, the model will use the default locale.
                        "verbose": bool  # Optional. An indication whether the model should
                          produce verbose output.
                    }
                }

                # response body for status code(s): 202
                response == {
                    "modelVersion": "str",  # The version of the model used for inference,
                      expressed as the model date. Required.
                    "patientResults": [
                        {
                            "inferences": [
                                radiology_insights_inference
                            ],
                            "patientId": "str"  # Identifier given for the patient in the
                              request. Required.
                        }
                    ]
                }
        """

    @overload
    async def begin_infer_radiology_insights(
        self, body: JSON, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.RadiologyInsightsInferenceResult]:
        """Create Radiology Insights job.

        Creates a Radiology Insights job with the given request body.

        :param body: Required.
        :type body: JSON
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :return: An instance of AsyncLROPoller that returns RadiologyInsightsInferenceResult. The
         RadiologyInsightsInferenceResult is compatible with MutableMapping
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.healthinsights.radiologyinsights.models.RadiologyInsightsInferenceResult]
        :raises ~azure.core.exceptions.HttpResponseError:

        Example:
            .. code-block:: python

                # response body for status code(s): 202
                response == {
                    "modelVersion": "str",  # The version of the model used for inference,
                      expressed as the model date. Required.
                    "patientResults": [
                        {
                            "inferences": [
                                radiology_insights_inference
                            ],
                            "patientId": "str"  # Identifier given for the patient in the
                              request. Required.
                        }
                    ]
                }
        """

    @overload
    async def begin_infer_radiology_insights(
        self, body: IO[bytes], *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.RadiologyInsightsInferenceResult]:
        """Create Radiology Insights job.

        Creates a Radiology Insights job with the given request body.

        :param body: Required.
        :type body: IO[bytes]
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :return: An instance of AsyncLROPoller that returns RadiologyInsightsInferenceResult. The
         RadiologyInsightsInferenceResult is compatible with MutableMapping
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.healthinsights.radiologyinsights.models.RadiologyInsightsInferenceResult]
        :raises ~azure.core.exceptions.HttpResponseError:

        Example:
            .. code-block:: python

                # response body for status code(s): 202
                response == {
                    "modelVersion": "str",  # The version of the model used for inference,
                      expressed as the model date. Required.
                    "patientResults": [
                        {
                            "inferences": [
                                radiology_insights_inference
                            ],
                            "patientId": "str"  # Identifier given for the patient in the
                              request. Required.
                        }
                    ]
                }
        """

    @distributed_trace_async
    async def begin_infer_radiology_insights(
        self, body: Union[_models.RadiologyInsightsData, JSON, IO[bytes]], **kwargs: Any
    ) -> AsyncLROPoller[_models.RadiologyInsightsInferenceResult]:
        # pylint: disable=line-too-long
        """Create Radiology Insights job.

        Creates a Radiology Insights job with the given request body.

        :param body: Is one of the following types: RadiologyInsightsData, JSON, IO[bytes] Required.
        :type body: ~azure.healthinsights.radiologyinsights.models.RadiologyInsightsData or JSON or
         IO[bytes]
        :return: An instance of AsyncLROPoller that returns RadiologyInsightsInferenceResult. The
         RadiologyInsightsInferenceResult is compatible with MutableMapping
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.healthinsights.radiologyinsights.models.RadiologyInsightsInferenceResult]
        :raises ~azure.core.exceptions.HttpResponseError:

        Example:
            .. code-block:: python

                # JSON input template you can fill out and use as your body input.
                body = {
                    "patients": [
                        {
                            "id": "str",  # A given identifier for the patient. Has to be
                              unique across all patients in a single request. Required.
                            "encounters": [
                                {
                                    "id": "str",  # The id of the visit.
                                      Required.
                                    "class": "str",  # Optional. The class of the
                                      encounter. Known values are: "inpatient", "ambulatory",
                                      "observation", "emergency", "virtual", and "healthHome".
                                    "period": {
                                        "end": "2020-02-20 00:00:00",  #
                                          Optional. End time with inclusive boundary, if not ongoing.
                                        "start": "2020-02-20 00:00:00"  #
                                          Optional. Starting time with inclusive boundary.
                                    }
                                }
                            ],
                            "info": {
                                "birthDate": "2020-02-20",  # Optional. The patient's
                                  date of birth.
                                "clinicalInfo": [
                                    {
                                        "resourceType": "str",  # The type of
                                          resource. Required.
                                        "id": "str",  # Optional. Resource
                                          Id.
                                        "implicitRules": "str",  # Optional.
                                          A set of rules under which this content was created.
                                        "language": "str",  # Optional.
                                          Language of the resource content.
                                        "meta": {
                                            "lastUpdated": "str",  #
                                              Optional. When the resource last changed - e.g. when the
                                              version changed.
                                            "profile": [
                                                "str"  # Optional. A
                                                  list of profiles (references to `StructureDefinition
                                                  <https://www.hl7.org/fhir/structuredefinition.html>`_
                                                  resources) that this resource claims to conform to.
                                                  The URL is a reference to `StructureDefinition.url
                                                  <https://www.hl7.org/fhir/structuredefinition-definitions.html#StructureDefinition.url>`_.
                                            ],
                                            "security": [
                                                {
                                                    "code":
                                                      "str",  # Optional. Symbol in syntax defined by
                                                      the system.
                                                    "display":
                                                      "str",  # Optional. Representation defined by the
                                                      system.
                                                    "extension":
                                                      [
                                                        {
                "url": "str",  # Source of the definition
                                                              for the extension code - a logical name
                                                              or a URL. Required.
                "valueBoolean": bool,  # Optional. Value
                                                              as boolean.
                "valueCodeableConcept": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional. Plain text
                                                                  representation of the concept.
                },
                "valueDateTime": "str",  # Optional.
                                                              Value as dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                              integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time
                                                                  with inclusive boundary, if not
                                                                  ongoing.
                "start": "str"  # Optional. Starting
                                                                  time with inclusive boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                                  alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "system": "str",  # Optional. The
                                                                      namespace for the identifier
                                                                      value.
                "type": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional.
                                                                          Plain text representation of
                                                                          the concept.
                },
                "use": "str",  # Optional. usual
                                                                      | official | temp | secondary |
                                                                      old (If known).
                "value": "str"  # Optional. The
                                                                      value that is unique.
                },
                "reference": "str",  # Optional.
                                                                  Literal reference, Relative, internal
                                                                  or absolute URL.
                "type": "str"  # Optional. Type the
                                                                  reference refers to (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                                  points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "period": 0.0,  # Number of
                                                                  milliseconds between samples.
                                                                  Required.
                "data": "str",  # Optional. Decimal
                                                                  values with spaces, or "E" | "U" |
                                                                  "L".
                "factor": 0.0,  # Optional. Multiply
                                                                  data by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                                  limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                                  limit of detection.
                },
                "valueString": "str",  # Optional. Value
                                                              as string.
                "valueTime": "12:30:00"  # Optional.
                                                              Value as time (hh:mm:ss).
                                                        }
                                                    ],
                                                    "id": "str",
                                                      # Optional. Unique id for inter-element
                                                      referencing.
                                                    "system":
                                                      "str",  # Optional. Identity of the terminology
                                                      system.
                                                    "version":
                                                      "str"  # Optional. Version of the system - if
                                                      relevant.
                                                }
                                            ],
                                            "source": "str",  # Optional.
                                              A uri that identifies the source system of the resource.
                                              This provides a minimal amount of Provenance information
                                              that can be used to track or differentiate the source of
                                              information in the resource. The source may identify
                                              another FHIR server, document, message, database, etc.
                                            "tag": [
                                                {
                                                    "code":
                                                      "str",  # Optional. Symbol in syntax defined by
                                                      the system.
                                                    "display":
                                                      "str",  # Optional. Representation defined by the
                                                      system.
                                                    "extension":
                                                      [
                                                        {
                "url": "str",  # Source of the definition
                                                              for the extension code - a logical name
                                                              or a URL. Required.
                "valueBoolean": bool,  # Optional. Value
                                                              as boolean.
                "valueCodeableConcept": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional. Plain text
                                                                  representation of the concept.
                },
                "valueDateTime": "str",  # Optional.
                                                              Value as dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                              integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time
                                                                  with inclusive boundary, if not
                                                                  ongoing.
                "start": "str"  # Optional. Starting
                                                                  time with inclusive boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                }
                },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                                  alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "system": "str",  # Optional. The
                                                                      namespace for the identifier
                                                                      value.
                "type": {
                "coding": [
                ...
                ],
                "text": "str"  # Optional.
                                                                          Plain text representation of
                                                                          the concept.
                },
                "use": "str",  # Optional. usual
                                                                      | official | temp | secondary |
                                                                      old (If known).
                "value": "str"  # Optional. The
                                                                      value that is unique.
                },
                "reference": "str",  # Optional.
                                                                  Literal reference, Relative, internal
                                                                  or absolute URL.
                "type": "str"  # Optional. Type the
                                                                  reference refers to (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                                  points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                      form of the unit.
                "comparator": "str",  # Optional.
                                                                      < | <= | >= | > - how to
                                                                      understand the value.
                "system": "str",  # Optional.
                                                                      System that defines coded unit
                                                                      form.
                "unit": "str",  # Optional. Unit
                                                                      representation.
                "value": 0.0  # Optional.
                                                                      Numerical value (with implicit
                                                                      precision).
                },
                "period": 0.0,  # Number of
                                                                  milliseconds between samples.
                                                                  Required.
                "data": "str",  # Optional. Decimal
                                                                  values with spaces, or "E" | "U" |
                                                                  "L".
                "factor": 0.0,  # Optional. Multiply
                                                                  data by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                                  limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                                  limit of detection.
                },
                "valueString": "str",  # Optional. Value
                                                              as string.
                "valueTime": "12:30:00"  # Optional.
                                                              Value as time (hh:mm:ss).
                                                        }
                                                    ],
                                                    "id": "str",
                                                      # Optional. Unique id for inter-element
                                                      referencing.
                                                    "system":
                                                      "str",  # Optional. Identity of the terminology
                                                      system.
                                                    "version":
                                                      "str"  # Optional. Version of the system - if
                                                      relevant.
                                                }
                                            ],
                                            "versionId": "str"  #
                                              Optional. The version specific identifier, as it appears
                                              in the version portion of the URL. This value changes
                                              when the resource is created, updated, or deleted.
                                        }
                                    }
                                ],
                                "sex": "str"  # Optional. The patient's sex. Known
                                  values are: "female", "male", and "unspecified".
                            },
                            "patientDocuments": [
                                {
                                    "content": {
                                        "sourceType": "str",  # The type of
                                          the content's source. In case the source type is 'inline',
                                          the content is given as a string (for instance, text). In
                                          case the source type is 'reference', the content is given as
                                          a URI. Required. Known values are: "inline" and "reference".
                                        "value": "str"  # The content of the
                                          document, given either inline (as a string) or as a reference
                                          (URI). Required.
                                    },
                                    "id": "str",  # A given identifier for the
                                      document. Has to be unique across all documents for a single
                                      patient. Required.
                                    "type": "str",  # The type of the patient
                                      document, such as 'note' (text document) or 'fhirBundle' (FHIR
                                      JSON document). Required. Known values are: "note", "fhirBundle",
                                      "dicom", and "genomicSequencing".
                                    "administrativeMetadata": {
                                        "encounterId": "str",  # Optional.
                                          Reference to the encounter associated with the document.
                                        "orderedProcedures": [
                                            {
                                                "code": {
                                                    "coding": [
                                                        {
                "code": "str",  # Optional. Symbol in
                                                              syntax defined by the system.
                "display": "str",  # Optional.
                                                              Representation defined by the system.
                "extension": [
                {
                "url": "str",  # Source of the
                                                                      definition for the extension code
                                                                      - a logical name or a URL.
                                                                      Required.
                "valueBoolean": bool,  #
                                                                      Optional. Value as boolean.
                "valueCodeableConcept": ...,
                "valueDateTime": "str",  #
                                                                      Optional. Value as dateTime.
                "valueInteger": 0,  # Optional.
                                                                      Value as integer.
                "valuePeriod": {
                "end": "str",  # Optional.
                                                                          End time with inclusive
                                                                          boundary, if not ongoing.
                "start": "str"  # Optional.
                                                                          Starting time with inclusive
                                                                          boundary.
                },
                "valueQuantity": {
                "code": "str",  # Optional.
                                                                          Coded form of the unit.
                "comparator": "str",  #
                                                                          Optional. < | <= | >= | > -
                                                                          how to understand the value.
                "system": "str",  # Optional.
                                                                          System that defines coded
                                                                          unit form.
                "unit": "str",  # Optional.
                                                                          Unit representation.
                "value": 0.0  # Optional.
                                                                          Numerical value (with
                                                                          implicit precision).
                },
                "valueRange": {
                "high": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "low": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                }
                },
                "valueRatio": {
                "denominator": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "numerator": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                }
                },
                "valueReference": {
                "display": "str",  #
                                                                          Optional. Text alternative
                                                                          for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  #
                                                                                  Optional. End time
                                                                                  with inclusive
                                                                                  boundary, if not
                                                                                  ongoing.
                "start": "str"  #
                                                                                  Optional. Starting
                                                                                  time with inclusive
                                                                                  boundary.
                },
                "system": "str",  #
                                                                              Optional. The namespace
                                                                              for the identifier value.
                "type": ...,
                "use": "str",  #
                                                                              Optional. usual |
                                                                              official | temp |
                                                                              secondary | old (If
                                                                              known).
                "value": "str"  #
                                                                              Optional. The value that
                                                                              is unique.
                },
                "reference": "str",  #
                                                                          Optional. Literal reference,
                                                                          Relative, internal or
                                                                          absolute URL.
                "type": "str"  # Optional.
                                                                          Type the reference refers to
                                                                          (e.g. "Patient").
                },
                "valueSampledData": {
                "dimensions": 0,  # Number of
                                                                          sample points at each time
                                                                          point. Required.
                "origin": {
                "code": "str",  #
                                                                              Optional. Coded form of
                                                                              the unit.
                "comparator": "str",  #
                                                                              Optional. < | <= | >= | >
                                                                              - how to understand the
                                                                              value.
                "system": "str",  #
                                                                              Optional. System that
                                                                              defines coded unit form.
                "unit": "str",  #
                                                                              Optional. Unit
                                                                              representation.
                "value": 0.0  # Optional.
                                                                              Numerical value (with
                                                                              implicit precision).
                },
                "period": 0.0,  # Number of
                                                                          milliseconds between samples.
                                                                          Required.
                "data": "str",  # Optional.
                                                                          Decimal values with spaces,
                                                                          or "E" | "U" | "L".
                "factor": 0.0,  # Optional.
                                                                          Multiply data by this before
                                                                          adding to origin.
                "lowerLimit": 0.0,  #
                                                                          Optional. Lower limit of
                                                                          detection.
                "upperLimit": 0.0  #
                                                                          Optional. Upper limit of
                                                                          detection.
                },
                "valueString": "str",  #
                                                                      Optional. Value as string.
                "valueTime": "12:30:00"  #
                                                                      Optional. Value as time
                                                                      (hh:mm:ss).
                }
                ],
                "id": "str",  # Optional. Unique id for
                                                              inter-element referencing.
                "system": "str",  # Optional. Identity of
                                                              the terminology system.
                "version": "str"  # Optional. Version of
                                                              the system - if relevant.
                                                        }
                                                    ],
                                                    "text": "str"
                                                      # Optional. Plain text representation of the
                                                      concept.
                                                },
                                                "description": "str",
                                                  # Optional. Procedure description.
                                                "extension": [
                                                    {
                "url": "str",  # Source of the definition for
                                                          the extension code - a logical name or a URL.
                                                          Required.
                "valueBoolean": bool,  # Optional. Value as
                                                          boolean.
                "valueCodeableConcept": {
                "coding": [
                {
                "code": "str",  # Optional.
                                                                      Symbol in syntax defined by the
                                                                      system.
                "display": "str",  # Optional.
                                                                      Representation defined by the
                                                                      system.
                "extension": [
                ...
                ],
                "id": "str",  # Optional. Unique
                                                                      id for inter-element referencing.
                "system": "str",  # Optional.
                                                                      Identity of the terminology
                                                                      system.
                "version": "str"  # Optional.
                                                                      Version of the system - if
                                                                      relevant.
                }
                ],
                "text": "str"  # Optional. Plain text
                                                              representation of the concept.
                                                        },
                "valueDateTime": "str",  # Optional. Value as
                                                          dateTime.
                "valueInteger": 0,  # Optional. Value as
                                                          integer.
                "valuePeriod": {
                "end": "str",  # Optional. End time with
                                                              inclusive boundary, if not ongoing.
                "start": "str"  # Optional. Starting time
                                                              with inclusive boundary.
                                                        },
                "valueQuantity": {
                "code": "str",  # Optional. Coded form of
                                                              the unit.
                "comparator": "str",  # Optional. < | <=
                                                              | >= | > - how to understand the value.
                "system": "str",  # Optional. System that
                                                              defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                              representation.
                "value": 0.0  # Optional. Numerical value
                                                              (with implicit precision).
                                                        },
                "valueRange": {
                "high": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "low": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                }
                                                        },
                "valueRatio": {
                "denominator": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "numerator": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                }
                                                        },
                "valueReference": {
                "display": "str",  # Optional. Text
                                                              alternative for the resource.
                "identifier": {
                "assigner": ...,
                "period": {
                "end": "str",  # Optional. End
                                                                      time with inclusive boundary, if
                                                                      not ongoing.
                "start": "str"  # Optional.
                                                                      Starting time with inclusive
                                                                      boundary.
                },
                "system": "str",  # Optional. The
                                                                  namespace for the identifier value.
                "type": {
                "coding": [
                {
                "code": "str",  #
                                                                              Optional. Symbol in
                                                                              syntax defined by the
                                                                              system.
                "display": "str",  #
                                                                              Optional. Representation
                                                                              defined by the system.
                "extension": [
                ...
                ],
                "id": "str",  # Optional.
                                                                              Unique id for
                                                                              inter-element
                                                                              referencing.
                "system": "str",  #
                                                                              Optional. Identity of the
                                                                              terminology system.
                "version": "str"  #
                                                                              Optional. Version of the
                                                                              system - if relevant.
                }
                ],
                "text": "str"  # Optional. Plain
                                                                      text representation of the
                                                                      concept.
                },
                "use": "str",  # Optional. usual |
                                                                  official | temp | secondary | old (If
                                                                  known).
                "value": "str"  # Optional. The value
                                                                  that is unique.
                },
                "reference": "str",  # Optional. Literal
                                                              reference, Relative, internal or absolute
                                                              URL.
                "type": "str"  # Optional. Type the
                                                              reference refers to (e.g. "Patient").
                                                        },
                "valueSampledData": {
                "dimensions": 0,  # Number of sample
                                                              points at each time point. Required.
                "origin": {
                "code": "str",  # Optional. Coded
                                                                  form of the unit.
                "comparator": "str",  # Optional. < |
                                                                  <= | >= | > - how to understand the
                                                                  value.
                "system": "str",  # Optional. System
                                                                  that defines coded unit form.
                "unit": "str",  # Optional. Unit
                                                                  representation.
                "value": 0.0  # Optional. Numerical
                                                                  value (with implicit precision).
                },
                "period": 0.0,  # Number of milliseconds
                                                              between samples. Required.
                "data": "str",  # Optional. Decimal
                                                              values with spaces, or "E" | "U" | "L".
                "factor": 0.0,  # Optional. Multiply data
                                                              by this before adding to origin.
                "lowerLimit": 0.0,  # Optional. Lower
                                                              limit of detection.
                "upperLimit": 0.0  # Optional. Upper
                                                              limit of detection.
                                                        },
                "valueString": "str",  # Optional. Value as
                                                          string.
                "valueTime": "12:30:00"  # Optional. Value as
                                                          time (hh:mm:ss).
                                                    }
                                                ]
                                            }
                                        ]
                                    },
                                    "authors": [
                                        {
                                            "fullName": "str",  #
                                              Optional. Text representation of the full name.
                                            "id": "str"  # Optional.
                                              author id.
                                        }
                                    ],
                                    "clinicalType": "str",  # Optional. The type
                                      of the clinical document. Known values are: "consultation",
                                      "dischargeSummary", "historyAndPhysical", "radiologyReport",
                                      "procedure", "progress", "laboratory", and "pathologyReport".
                                    "createdDateTime": "2020-02-20 00:00:00",  #
                                      Optional. The date and time when the document was created.
                                    "language": "str",  # Optional. A 2 letter
                                      ISO 639-1 representation of the language of the document.
                                    "specialtyType": "str"  # Optional. specialty
                                      type the document. Known values are: "pathology" and "radiology".
                                }
                            ]
                        }
                    ],
                    "configuration": {
                        "includeEvidence": bool,  # Optional. An indication whether the
                          model's output should include evidence for the inferences.
                        "inferenceOptions": {
                            "findingOptions": {
                                "provideFocusedSentenceEvidence": bool  # Optional.
                                  If this is true, provide the sentence that contains the first token
                                  of the finding's clinical indicator (i.e. the medical problem), if
                                  there is one. This sentence is provided as an extension with url
                                  'ci_sentence', next to the token evidence. Default is false.
                            },
                            "followupRecommendationOptions": {
                                "includeRecommendationsInReferences": bool,  #
                                  Optional. Include/Exclude follow-up recommendations in references to
                                  a guideline or article. Default is false.
                                "includeRecommendationsWithNoSpecifiedModality":
                                  bool,  # Optional. Include/Exclude follow-up recommendations without
                                  a specific radiology procedure. Default is false.
                                "provideFocusedSentenceEvidence": bool  # Optional.
                                  If this is true, provide one or more sentences as evidence for the
                                  recommendation, next to the token evidence. The start and end
                                  positions of these sentences will be put in an extension with url
                                  'modality_sentences'. Default is false.
                            }
                        },
                        "inferenceTypes": [
                            "str"  # Optional. This is a list of inference types to be
                              inferred for the current request. It could be used if only part of the
                              Radiology Insights inferences are required. If this list is omitted or
                              empty, the model will return all the inference types.
                        ],
                        "locale": "str",  # Optional. Local for the model to use. If not
                          specified, the model will use the default locale.
                        "verbose": bool  # Optional. An indication whether the model should
                          produce verbose output.
                    }
                }

                # response body for status code(s): 202
                response == {
                    "modelVersion": "str",  # The version of the model used for inference,
                      expressed as the model date. Required.
                    "patientResults": [
                        {
                            "inferences": [
                                radiology_insights_inference
                            ],
                            "patientId": "str"  # Identifier given for the patient in the
                              request. Required.
                        }
                    ]
                }
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = kwargs.pop("params", {}) or {}

        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.RadiologyInsightsInferenceResult] = kwargs.pop("cls", None)
        polling: Union[bool, AsyncPollingMethod] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        if cont_token is None:
            raw_result = await self._infer_radiology_insights_initial(
                body=body, content_type=content_type, cls=lambda x, y, z: x, headers=_headers, params=_params, **kwargs
            )
        kwargs.pop("error_map", None)

        def get_long_running_output(pipeline_response):
            response_headers = {}
            response = pipeline_response.http_response
            response_headers["Operation-Location"] = self._deserialize(
                "str", response.headers.get("Operation-Location")
            )
            response_headers["Retry-After"] = self._deserialize("int", response.headers.get("Retry-After"))
            response_headers["Repeatability-Result"] = self._deserialize(
                "str", response.headers.get("Repeatability-Result")
            )

            deserialized = _deserialize(_models.RadiologyInsightsInferenceResult, response.json().get("result"))
            if cls:
                return cls(pipeline_response, deserialized, response_headers)  # type: ignore
            return deserialized

        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.endpoint", self._config.endpoint, "str", skip_quote=True),
        }

        if polling is True:
            polling_method: AsyncPollingMethod = cast(
                AsyncPollingMethod,
                AsyncLROBasePolling(lro_delay, path_format_arguments=path_format_arguments, **kwargs),
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod, AsyncNoPolling())
        else:
            polling_method = polling
        if cont_token:
            return AsyncLROPoller[_models.RadiologyInsightsInferenceResult].from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
                client=self._client,
                deserialization_callback=get_long_running_output,
            )
        return AsyncLROPoller[_models.RadiologyInsightsInferenceResult](
            self._client, raw_result, get_long_running_output, polling_method  # type: ignore
        )
